pub(crate) struct AudioListenerNode {
channel_info: ChannelInfo,
position_x: Param,
position_y: Param,
position_z: Param,
forward_x: Param,
forward_y: Param,
forward_z: Param,
up_x: Param,
up_y: Param,
up_z: Param,
}Expand description
AudioListeners are fake nodes; from the user’s point of view they’re a non-node entity with zero inputs and outputs, but with AudioParams that can be manipulated.
Internally, PannerNodes all have an implicit PortIndex::Listener connection from a hidden output port on AudioListeners that contains all the position data.
This encodes the otherwise implicit dependency between AudioListeners and PannerNodes so that if there is a cycle involving panner nodes and the audio params on the listener, the cycle breaking algorithm can deal with it.
Fields
channel_info: ChannelInfoposition_x: Paramposition_y: Paramposition_z: Paramforward_x: Paramforward_y: Paramforward_z: Paramup_x: Paramup_y: Paramup_z: ParamImplementations